← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/frisians_string_fixes into lp:widelands

 

GunChleoc has proposed merging lp:~widelands-dev/widelands/frisians_string_fixes into lp:widelands.

Commit message:
Fixed typos and string consistency issues, mostly for the Frisians.

Requested reviews:
  Widelands Developers (widelands-dev)

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/frisians_string_fixes/+merge/342702
-- 
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/frisians_string_fixes into lp:widelands.
=== modified file 'data/campaigns/fri01.wmf/scripting/texts.lua'
--- data/campaigns/fri01.wmf/scripting/texts.lua	2018-03-11 15:55:43 +0000
+++ data/campaigns/fri01.wmf/scripting/texts.lua	2018-04-05 06:03:52 +0000
@@ -98,7 +98,7 @@
    title=_"Train your soldiers",
    number = 1,
    body = objective_text(_"Training Soldiers",
-      li(_[[Train a soldier to the highest possible level. Soldiers are trained in small training camps and large training arenas. We will need a gold mine, a tailor’s shop to sew better armor, and a large armor smithy for better weapons and helmets.]])
+      li(_[[Train a soldier to the highest possible level. Soldiers are trained in training camps and training arenas. We will need a gold mine, a tailor’s shop to sew better armor, and a large armor smithy for better weapons and helmets.]])
    ),
 }
 obj_defeat_enemy = {
@@ -312,7 +312,7 @@
       _([[We are recruiting soldiers easily enough, but they are fairly weak. We must train our soldiers if they are to beat the enemy.]])
        .. paragraphdivider() ..
       -- TRANSLATORS: Reebaud – train soldiers 1
-      _([[Soldiers are trained in basic attack, health and defense by a small training camp. They can learn the finer points in a large training arena.]])),
+      _([[Soldiers are trained in basic attack, health and defense by a training camp. They can learn the finer points in a large training arena.]])),
 }
 training_2 = {
    title =_ "Training Soldiers",

=== modified file 'data/tribes/buildings/partially_finished/dismantlesite/helptexts.lua'
--- data/tribes/buildings/partially_finished/dismantlesite/helptexts.lua	2016-10-18 07:10:54 +0000
+++ data/tribes/buildings/partially_finished/dismantlesite/helptexts.lua	2018-04-05 06:03:52 +0000
@@ -13,7 +13,7 @@
 
 function building_helptext_purpose()
    -- TRANSLATORS: Purpose helptext for a building
-   return pgettext("building", "A building is being dismantled at this dismantlesite, returning some of the resources that were used during this building’s construction to your tribe’s stores.")
+   return pgettext("building", "A building is being dismantled at this dismantle site, returning some of the resources that were used during this building’s construction to your tribe’s stores.")
 end
 
 function building_helptext_note()

=== modified file 'data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua'
--- data/txts/tips/frisians.lua	2017-07-07 07:48:20 +0000
+++ data/txts/tips/frisians.lua	2018-04-05 06:03:52 +0000
@@ -5,7 +5,7 @@
       seconds = 9
    },
    {
-      text = _"Always build a forester´s house, so you will not run out of logs.",
+      text = _"Always build a forester’s house, so you will not run out of logs.",
       seconds = 4
    },
    {


Follow ups
--- data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua	2018-02-13 14:26:22 +0000
+++ data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua	2018-04-05 06:03:52 +0000
@@ -112,8 +112,8 @@
          },
       },
       produce_3 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging a scythe because ...
-         descname = _"forging a scythe",
+         -- TRANSLATORS: Completed/Skipped/Did not start making a scythe because ...
+         descname = _"making a scythe",
          actions = {
             "return=skipped unless economy needs scythe",
             "sleep=32000",
@@ -123,8 +123,8 @@
          },
       },
       produce_4 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging a shovel because ...
-         descname = _"forging a shovel",
+         -- TRANSLATORS: Completed/Skipped/Did not start making a shovel because ...
+         descname = _"making a shovel",
          actions = {
             "return=skipped unless economy needs shovel",
             "sleep=32000",
@@ -145,8 +145,8 @@
          },
       },
       produce_6 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging a hunting spear because ...
-         descname = _"forging a hunting spear",
+         -- TRANSLATORS: Completed/Skipped/Did not start making a hunting spear because ...
+         descname = _"making a hunting spear",
          actions = {
             "return=skipped unless economy needs hunting_spear",
             "sleep=32000",
@@ -189,8 +189,8 @@
          },
       },
       produce_10 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging a hammer because ...
-         descname = _"forging a hammer",
+         -- TRANSLATORS: Completed/Skipped/Did not start making a hammer because ...
+         descname = _"making a hammer",
          actions = {
             "return=skipped unless economy needs hammer",
             "sleep=32000",
@@ -200,8 +200,8 @@
          },
       },
       produce_11 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging fire tongs because ...
-         descname = _"forging fire tongs",
+         -- TRANSLATORS: Completed/Skipped/Did not start making fire tongs because ...
+         descname = _"making fire tongs",
          actions = {
             "return=skipped unless economy needs fire_tongs",
             "sleep=32000",

=== modified file 'data/tribes/buildings/productionsites/frisians/charcoal_kiln/init.lua'
--- data/tribes/buildings/productionsites/frisians/charcoal_kiln/init.lua	2018-02-23 07:18:54 +0000
+++ data/tribes/buildings/productionsites/frisians/charcoal_kiln/init.lua	2018-04-05 06:03:52 +0000
@@ -57,8 +57,8 @@
 
    programs = {
       work = {
-         -- TRANSLATORS: Completed/Skipped/Did not start burning charcoal because ...
-         descname = _"burning charcoal",
+         -- TRANSLATORS: Completed/Skipped/Did not start producing coal because ...
+         descname = _"producing coal",
          actions = {
             "sleep=30000",
             "return=skipped unless economy needs coal",

=== modified file 'data/tribes/buildings/productionsites/frisians/well/init.lua'
--- data/tribes/buildings/productionsites/frisians/well/init.lua	2018-02-16 14:53:04 +0000
+++ data/tribes/buildings/productionsites/frisians/well/init.lua	2018-04-05 06:03:52 +0000
@@ -46,8 +46,8 @@
 
    programs = {
       work = {
-         -- TRANSLATORS: Completed/Skipped/Did not start mining water because ...
-         descname = _"mining water",
+         -- TRANSLATORS: Completed/Skipped/Did not start working because ...
+         descname = _"working",
          actions = {
             "sleep=20000",
             "animate=working 20000",

=== modified file 'data/txts/tips/frisians.lua'